
:autogenerated:

newtonprop.propagator module
============================

.. currentmodule:: newtonprop.propagator

.. automodule:: newtonprop.propagator
    :members: step
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        step





    ``__all__``: :func:`step <newtonprop.propagator.step>`



    Reference
    ---------